# Clifold
## Usage
```
usage: clif <arg> [options]

🚀 A CLI tool for scaffolding any Python Projects 🚀

Argument:
  project_name    Project name to create with venv

Options:
  -g, --git       Make git initialization
  -ng, --no-git   Skip git initialization
  -p, --pkg       Ask packages to install
  -np, --no-pkg   Skip packages installation
  -i, --init      Create setup.py file
  -ni, --no-init  Skip setup.py file
  -V, --version   Output version number
  -h, --help      Output usage information
```